@@ -138,7 +138,7 @@ affile_sd_notify(LogPipe *s, LogPipe *sender, gint notify_code, gpointer user_da
         
         if (affile_sd_open_file(self, &fd))
           {
-            self->reader = log_reader_new(fd_read_new(fd, 0), LR_LOCAL | LR_NOMREAD, s, &self->reader_options);
+            self->reader = log_reader_new(fd_read_new(fd, 0), LR_LOCAL | (self->reader_options.follow_freq == 0 ? LR_NOMREAD : 0), s, &self->reader_options);
             log_pipe_append(self->reader, s);
             if (!log_pipe_init(self->reader, NULL, NULL))
               {
@@ -184,7 +184,7 @@ affile_sd_init(LogPipe *s, GlobalConfig *cfg, PersistentConfig *persist)
       
       fdr = fd_read_new(fd, 0);
       fdr->timeout = 10;
-      self->reader = log_reader_new(fdr, LR_LOCAL | LR_NOMREAD, s, &self->reader_options);
+      self->reader = log_reader_new(fdr, LR_LOCAL | (self->reader_options.follow_freq == 0 ? LR_NOMREAD : 0), s, &self->reader_options);
 
       if (persist)
         {
