@@ -30,6 +30,10 @@
 #include <fcntl.h>
 #include <unistd.h>
 
+#ifndef HAVE_GETUTENT
+#include "utils.h"
+#endif
+
 typedef struct _AFUserDestDriver
 {
   LogDriver super;
@@ -105,8 +109,7 @@ afuser_dd_queue(LogPipe *s, LogMessage *msg, gint path_flags)
     }
   endutent();
 finish:
-  if ((path_flags & PF_FLOW_CTL_OFF) == 0)
-    log_msg_ack(msg);
+  log_msg_ack(msg, path_flags);
   log_msg_unref(msg);
 }
 
