@@ -310,7 +310,7 @@ typedef union YYSTYPE
 	FilterExprNode *node;
 }
 /* Line 1489 of yacc.c.  */
-#line 314 "y.tab.h"
+#line 314 "cfg-grammar.h"
 	YYSTYPE;
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
