@@ -18,23 +18,27 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  
  */
-
+  
 #ifndef FDWRITE_H_INCLUDED
 #define FDWRITE_H_INCLUDED
 
 #include "syslog-ng.h"
 #include <unistd.h>
 
-typedef struct _FDWrite
+typedef struct _FDWrite FDWrite;
+
+struct _FDWrite
 {
   gint fd;
   GIOCondition cond;
-  gboolean fsync;
+  gboolean fsync:1,
+           append:1;
   gint timeout;
-  size_t (*write)(struct _FDWrite *, const void *buf, size_t count);
-} FDWrite;
+  size_t (*write)(FDWrite *self, const void *buf, size_t count);
+  void (*free_fn)(FDWrite *self);
+};
 
 static inline ssize_t 
 fd_write(FDWrite *s, const void *buf, size_t count)
@@ -45,5 +49,6 @@ fd_write(FDWrite *s, const void *buf, size_t count)
 FDWrite *fd_write_new(gint fd);
 void fd_write_free(FDWrite *self);
 
+void fd_write_free_method(FDWrite *self);
 
 #endif
