@@ -53,8 +53,6 @@
 #define TS_FMT_FULL  2
 #define TS_FMT_UNIX  3
 
-typedef struct _LogMessage LogMessage;
-
 typedef void (*LMAckFunc)(LogMessage *lm, gpointer user_data);
 
 typedef struct _LogStamp
@@ -72,11 +70,10 @@ struct _LogMessage
 {
   GAtomicCounter ref_cnt;
   GAtomicCounter ack_cnt;
+  guint16 pri;
   guint8 flags;
-  guint8 pri;
   /* meta information */
   guint8 num_re_matches;
-  guint8 __pad1;
   gchar *source_group;
   GSockAddr *saddr;
   LMAckFunc ack_func;
