@@ -34,6 +34,11 @@ level_range(gchar *from, gchar *to)
   return syslog_make_range(r1, r2);
 }
 
+void 
+main_loop_wakeup(void)
+{
+}
+
 void
 testcase(gchar *msg, 
          gint parse_flags,
